--[[

Version 0.01 - Initial release of Concept code to wowace svn

Author : Levva of EU Khadgar 
	
--]]

local L = LibStub("AceLocale-3.0"):GetLocale("RaidInviter")
local AceAddon = LibStub("AceAddon-3.0")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");
RaidInviter = AceAddon:NewAddon("RaidInviter", "AceConsole-3.0", "AceEvent-3.0")
local REVISION = tonumber(("$Revision: 4 $"):match("%d+"))

RaidInviter.textures = {}
RaidInviter.borders = {}
RaidInviter.fonts = {}
RaidInviter.sounds = {}
RaidInviter.barBackdrop = {
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
		tile = false, tileSize = 0, edgeSize = 12,
		insets = { left = 2, right = 2, top = 2, bottom = 2 }
	}
RaidInviter.frameBackdrop ={
		bgFile = "Interface/Tooltips/UI-Tooltip-Background",
		--edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
		tile = false, tileSize = 0, edgeSize = 12,
		insets = { left = 0, right = 0, top = 0, bottom = 0 }
	}

-------------------
-- Config details
-------------------

RaidInviter.defaults = {
	char = {
		message = "Welcome Home!",
		relativeTo = "UIParent",
		relativePoint = "CENTER",
		point = "CENTER",
		texture = "Blizzard",
		msgfont = "Friz Quadrata TT",
		msgfontsize = 24,
		msgfonteffect = "none",
		border = "None",
		barborder = "Blizzard Tooltip",
		xOffset = 0,
		yOffset = 0,
		fWidth = 300,
		fHeight = 175,
		scale = 1,
		debug = false,
	}
}

-----------------------------------------
-- Initialisation & Startup Routines
-----------------------------------------

function RaidInviter:OnInitialize()
	local AceConfigReg = LibStub("AceConfigRegistry-3.0")
	local AceConfigDialog = LibStub("AceConfigDialog-3.0")

	self.db = LibStub("AceDB-3.0"):New("RaidInviterDBPC", RaidInviter.defaults, "char")
	LibStub("AceConfig-3.0"):RegisterOptionsTable("RaidInviter", self:GetOptions(), {"RaidInviter", "qi"} )
	media.RegisterCallback(self, "LibSharedMedia_Registered")
	
	-- Add the options to blizzard frame (add them backwards so they show up in the proper order
	self.optionsFrame = AceConfigDialog:AddToBlizOptions("RaidInviter","RaidInviter")
	self.optionsFrame[L["About"]] = LibStub("LibAboutPanel").new("RaidInviter", "RaidInviter")
	self.db:RegisterDefaults(self.defaults)
	local version = GetAddOnMetadata("RaidInviter","Version")
	self.version = ("RaidInviter v%s (r%s)"):format(version, REVISION)
	self:Print(self.version.." Loaded.")
end

function RaidInviter:OnDisable()
    -- Called when the addon is disabled
end

function RaidInviter:OnEnable()
	self:LibSharedMedia_Registered()
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
	self:RegisterEvent("UPDATE_BINDINGS")
end

function RaidInviter:LibSharedMedia_Registered()
	for k, v in pairs(media:List("statusbar")) do
		self.textures[v] = v
	end
	for k, v in pairs(media:List("border")) do
		self.borders[v] = v
	end
	for k, v in pairs(media:List("font")) do
		self.fonts[v] = v
	end
	for k, v in pairs(media:List("sound")) do
		self.sounds[v] = v
	end
end

----------------------
-- Event Routines
----------------------

function RaidInviter:PLAYER_ENTERING_WORLD()
	self:CreateInviteFrame()
	self:UpdateInviteFrame()
end

function RaidInviter:UPDATE_BINDINGS()
--~ 	self:UpdateBindings()
end

----------------------
-- Frame Routines
----------------------

function RaidInviter:CreateInviteFrame()
	self.InviteFrame = CreateFrame("Frame", "RaidInviterBase", UIParent)
	self.InviteFrame:SetScale(self.db.char.scale)
	self.InviteFrame:SetFrameStrata("BACKGROUND")
	self.InviteFrame:SetWidth(self.db.char.fWidth + self.db.char.fHeight / 7)
	self.InviteFrame:SetHeight(self.db.char.fHeight)
	self.InviteFrame:SetBackdrop(self.frameBackdrop)
	self.InviteFrame:SetBackdropColor(1, 1, 1, 0)
	self.InviteFrame:SetMovable(true)
	self.InviteFrame:RegisterForDrag("LeftButton")
	self.InviteFrame:SetPoint(self.db.char.point, self.db.char.relativeTo, self.db.char.relativePoint, self.db.char.xOffset, self.db.char.yOffset)
	self.InviteFrame:SetScript("OnDragStart", 
		function()
			self.InviteFrame:StartMoving();
		end );
	self.InviteFrame:SetScript("OnDragStop",
		function()
			self.InviteFrame:StopMovingOrSizing();
			self.InviteFrame:SetScript("OnUpdate", nil);
			self:FinishedMoving(self.db.char, self.InviteFrame);
		end );
	self.InviteFrame.Event = CreateEventListDropdown()
	self.InviteFrame.playerList = CreatePlayerListFrame()
	self.InviteFrame.raidRoleComposition,  self.InviteFrame.raidClassComposition = CreateRaidRoleFrames()
	self.InviteFrame:Show()
end

function RaidInviter:CreateEventListDropdown()
	local eventList 
	return eventList
end

function RaidInviter:CreatePlayerListFrame()
	local playerList = CreateFrame("Frame", "RaidInviterPlayerList", self.InviteFrame)
	return playerList
end

function RaidInviter:CreatePlayerListFrame()
	local roleCompostion = CreateFrame("Frame", "RaidInviterRoleComposition", self.InviteFrame)
	local classCompostion = CreateFrame("Frame", "RaidInviterClassComposition", self.InviteFrame)
	return roleComposition, classComposition
end


function RaidInviter:UpdateInviteFrame()

end